## Virtual Resource Management in Cloudless System

List of system jobs encapsulated in UDP packets which will be exchanged
between worker and coordinator hosts inside an SDN environment.

- ProbeInit: sent by coordinator host.
- ProbeAck: sent by worker host.